/* This stylesheet is generated, DO NOT EDIT */
/* Copyright 2009, 2015 Red Hat, Inc.
 *
 * Portions adapted from Mx's data/style/default.css
 *   Copyright 2009 Intel Corporation
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 2.1, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */
/* GLOBALS */
* {
  transition-duration: 0.15s;
}

stage {
  font-family: Fira Sans, Cantarell, Sans-Serif;
  font-size: 10.5pt;
  font-weight: 400;
  color: rgba(87, 79, 74, 0.87);
}

/* WIDGETS */
/* Buttons */
.button {
  min-height: 36px;
  padding: 0 16px;
  border-width: 0;
  border-radius: 2px;
  font-size: 10.5pt;
  font-weight: 500;
  color: rgba(87, 79, 74, 0.75);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.button:hover {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(87, 79, 74, 0.12);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.button:active {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(87, 79, 74, 0.26);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.button:insensitive {
  color: rgba(87, 79, 74, 0.26);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.button:focus {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(250, 164, 26, 0.3);
  text-shadow: none;
  icon-shadow: none;
  box-shadow: 0 0 transparent;
}

.modal-dialog-linked-button {
  min-height: 40px;
  padding: 0 16px;
  border-top: 1px solid rgba(0, 0, 0, 0.1) !important;
  border-right-width: 0;
  font-size: 10.5pt;
  font-weight: 500;
  color: rgba(87, 79, 74, 0.75);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.modal-dialog-linked-button:hover {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(87, 79, 74, 0.12);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.modal-dialog-linked-button:active {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(87, 79, 74, 0.26);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.modal-dialog-linked-button:insensitive {
  color: rgba(87, 79, 74, 0.26);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.modal-dialog-linked-button:focus {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(250, 164, 26, 0.3);
  text-shadow: none;
  icon-shadow: none;
  box-shadow: 0 0 transparent;
}

.modal-dialog-linked-button:first-child {
  border-radius: 0px 0px 0px 2px;
}

.modal-dialog-linked-button:last-child {
  border-right-width: 0px;
  border-radius: 0px 0px 2px 0px;
}

.modal-dialog-linked-button:first-child:last-child {
  border-right-width: 0px;
  border-radius: 0px 0px 2px 2px;
}

/* Check Boxes */
.check-box * {
  min-height: 20px;
  padding: 8px 0;
}

.check-box StBoxLayout {
  spacing: 8px;
}

.check-box StBin {
  width: 24px;
  height: 24px;
  padding: 6px;
  border-radius: 100px;
  background-image: url("assets/checkbox-off.svg");
}

.check-box:focus StBin {
  background-image: url("assets/checkbox-off.svg");
}

.check-box:hover StBin {
  background-color: rgba(87, 79, 74, 0.12);
}

.check-box:active StBin {
  background-color: rgba(87, 79, 74, 0.26);
}

.check-box:checked StBin {
  background-image: url("assets/checkbox.svg");
}

.check-box:focus:checked StBin {
  background-image: url("assets/checkbox.svg");
}

.check-box:hover:checked StBin {
  background-color: rgba(250, 164, 26, 0.15);
}

.check-box:active:checked StBin {
  background-color: rgba(250, 164, 26, 0.3);
}

/* Entries */
StEntry {
  min-height: 36px;
  padding: 0 8px;
  border-radius: 0;
  border-width: 0;
  color: rgba(87, 79, 74, 0.87);
  selection-background-color: #48b9c7;
  selected-color: #FFFFFF;
  font-size: 12pt;
  font-weight: 400;
  background-color: rgba(255, 255, 255, 0.01);
  border-color: transparent;
  box-shadow: inset 0 -1px rgba(87, 79, 74, 0.26);
}

StEntry:focus {
  border-color: transparent;
  box-shadow: inset 0 -2px #faa41a;
}

StEntry:insensitive {
  color: rgba(87, 79, 74, 0.38);
  border-color: transparent;
  box-shadow: inset 0 -1px rgba(87, 79, 74, 0.12);
}

StEntry StIcon.capslock-warning {
  icon-size: 16px;
  warning-color: #ffce51;
  padding: 0 0;
}

.candidate-popup-content {
  padding: 8px;
  spacing: 0;
}

.candidate-index {
  padding: 0 4px 0 0;
  color: rgba(87, 79, 74, 0.38);
}

.candidate-box:selected .candidate-index {
  color: rgba(255, 255, 255, 0.5);
}

.candidate-box {
  transition-duration: 0ms;
  min-height: 32px;
  padding: 0 8px;
  border-radius: 2px;
}

.candidate-box:hover {
  background-color: rgba(87, 79, 74, 0.12);
  color: rgba(87, 79, 74, 0.87);
}

.candidate-box:active {
  background-color: rgba(87, 79, 74, 0.26);
  color: rgba(87, 79, 74, 0.87);
}

.candidate-box:selected {
  background-color: #48b9c7;
  color: #FFFFFF;
}

.candidate-page-button-box {
  height: 32px;
}

.vertical .candidate-page-button-box {
  padding-top: 0;
}

.horizontal .candidate-page-button-box {
  padding-left: 0;
}

.candidate-page-button {
  min-width: 32px;
  min-height: 32px;
  padding: 0;
}

.candidate-page-button-previous {
  border-radius: 2px;
  border-right-width: 0;
}

.candidate-page-button-next {
  border-radius: 2px;
}

.candidate-page-button-icon {
  icon-size: 1.14286em;
}

.screen-shield-arrows {
  padding-bottom: 3em;
}

.screen-shield-arrows Gjs_Arrow {
  color: white;
  width: 80px;
  height: 48px;
  -arrow-thickness: 12px;
  -arrow-shadow: 0 1px 1.5px rgba(0, 0, 0, 0.12), 0 1px 1px rgba(0, 0, 0, 0.24);
}

.screen-shield-clock {
  color: white;
  text-shadow: 0 1px 1.5px rgba(0, 0, 0, 0.12), 0 1px 1px rgba(0, 0, 0, 0.24);
  font-weight: normal;
  text-align: center;
  padding-bottom: 1.5em;
}

.screen-shield-clock-time {
  font-size: 112px;
  font-weight: 300;
  text-shadow: 0 1px 1.5px rgba(0, 0, 0, 0.12), 0 1px 1px rgba(0, 0, 0, 0.24);
}

.screen-shield-clock-date {
  font-size: 45px;
  font-weight: 400;
}

.screen-shield-notifications-container {
  spacing: 6px;
  width: 30em;
  background-color: transparent;
  max-height: 500px;
}

.screen-shield-notifications-container .summary-notification-stack-scrollview {
  padding-top: 0;
  padding-bottom: 0;
}

.screen-shield-notifications-container .notification,
.screen-shield-notifications-container .screen-shield-notification-source {
  padding: 8px;
  border: none;
  background-color: #2e2927;
  color: #FFFFFF;
  border-radius: 2px;
}

.screen-shield-notifications-container .notification {
  margin-right: 16px;
}

.screen-shield-notification-label {
  min-height: 22px;
  padding: 2px 0px 0px 16px;
  font-weight: bold;
}

.screen-shield-notification-count-text {
  min-height: 22px;
  padding: 2px 0px 0px 16px;
  color: rgba(255, 255, 255, 0.7);
}

#panel.lock-screen {
  background-color: #2e2927;
}

.screen-shield-background {
  background: black;
  box-shadow: 0 19px 19px rgba(0, 0, 0, 0.6), 0 15px 6px rgba(0, 0, 0, 0.44);
}

#lockDialogGroup {
  background: #607D8B url("assets/noise-texture.svg");
  background-size: cover;
}

.login-dialog-banner-view {
  padding-top: 24px;
  max-width: 27em;
}

.login-dialog {
  border: none;
  background-color: transparent;
}

.login-dialog StEntry {
  color: #FFFFFF;
  selection-background-color: rgba(255, 255, 255, 0.3);
  selected-color: #FFFFFF;
  background-color: rgba(245, 245, 245, 0.01);
  border-color: transparent;
  box-shadow: inset 0 -1px rgba(255, 255, 255, 0.3);
}

.login-dialog StEntry:focus {
  border-color: transparent;
  box-shadow: inset 0 -2px #faa41a;
}

.login-dialog StEntry:insensitive {
  color: rgba(87, 79, 74, 0.38);
  border-color: transparent;
  box-shadow: inset 0 -1px rgba(255, 255, 255, 0.12);
  color: rgba(255, 255, 255, 0.5);
}

.login-dialog .modal-dialog-button-box {
  spacing: 3px;
}

.login-dialog .modal-dialog-button {
  padding: 0 16px;
  color: #FFFFFF;
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:hover, .login-dialog .modal-dialog-button:focus {
  color: #FFFFFF;
  background-color: rgba(255, 255, 255, 0.12);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:active {
  color: #FFFFFF;
  background-color: rgba(255, 255, 255, 0.3);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:insensitive {
  color: rgba(255, 255, 255, 0.3);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:default {
  color: #FFFFFF;
  background-color: #3e935b;
  border-color: transparent;
  box-shadow: 0 1px 1.5px rgba(0, 0, 0, 0.12), 0 1px 1px rgba(0, 0, 0, 0.24);
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:default:hover, .login-dialog .modal-dialog-button:default:focus {
  color: #FFFFFF;
  background-color: #3e935b;
  border-color: transparent;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.24), 0 3px 3px rgba(0, 0, 0, 0.345);
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:default:active {
  color: #FFFFFF;
  background-color: #78b38c;
  border-color: transparent;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.24), 0 3px 3px rgba(0, 0, 0, 0.345);
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog .modal-dialog-button:default:insensitive {
  color: rgba(255, 255, 255, 0.5);
  background-color: rgba(255, 255, 255, 0.12);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.login-dialog-logo-bin {
  padding: 24px 0px;
}

.login-dialog-banner {
  color: rgba(255, 255, 255, 0.7);
}

.login-dialog-button-box {
  spacing: 5px;
}

.login-dialog-message-warning {
  color: #ffce51;
}

.login-dialog-message-hint {
  padding-top: 0;
  padding-bottom: 20px;
}

.login-dialog-user-selection-box {
  padding: 100px 0px;
}

.login-dialog-not-listed-label {
  padding-left: 2px;
}

.login-dialog-not-listed-button:focus .login-dialog-not-listed-label,
.login-dialog-not-listed-button:hover .login-dialog-not-listed-label {
  color: #FFFFFF;
}

.login-dialog-not-listed-label {
  font-size: 1em;
  font-weight: bold;
  color: rgba(255, 255, 255, 0.7);
  padding-top: 1em;
}

.login-dialog-not-listed-label:hover {
  color: #FFFFFF;
}

.login-dialog-not-listed-label:focus {
  background-color: rgba(255, 255, 255, 0.12);
}

.login-dialog-user-list-view {
  -st-vfade-offset: 1em;
}

.login-dialog-user-list {
  spacing: 12px;
  padding: .2em;
  width: 27em;
}

.login-dialog-user-list:expanded .login-dialog-user-list-item:selected {
  background-color: rgba(255, 255, 255, 0.12);
  color: #FFFFFF;
}

.login-dialog-user-list:expanded .login-dialog-user-list-item:hover {
  background-color: rgba(255, 255, 255, 0.12);
  color: #FFFFFF;
}

.login-dialog-user-list:expanded .login-dialog-user-list-item:active {
  background-color: rgba(255, 255, 255, 0.3);
  color: #FFFFFF;
}

.login-dialog-user-list:expanded .login-dialog-user-list-item:logged-in {
  border-right: 2px solid #FFFFFF;
}

.login-dialog-user-list-item {
  border-radius: 2px;
  padding: 4px 4px 0;
  color: rgba(255, 255, 255, 0.7);
}

.login-dialog-user-list-item:ltr {
  padding-right: 1em;
}

.login-dialog-user-list-item:rtl {
  padding-left: 1em;
}

.login-dialog-user-list-item:hover {
  background-color: rgba(255, 255, 255, 0.12);
  color: #FFFFFF;
}

.login-dialog-user-list-item:active {
  background-color: rgba(255, 255, 255, 0.3);
  color: #FFFFFF;
}

.login-dialog-user-list-item .login-dialog-timed-login-indicator {
  height: 2px;
  margin: 2px 0 0 0;
  background-color: #FFFFFF;
}

.login-dialog-user-list-item:focus .login-dialog-timed-login-indicator {
  background-color: #FFFFFF;
}

.login-dialog-username,
.user-widget-label {
  color: #FFFFFF;
  font-size: 15pt;
  font-weight: 500;
  text-align: left;
  padding-left: 15px;
}

.user-widget-label:ltr {
  padding-left: 18px;
}

.user-widget-label:rtl {
  padding-right: 18px;
}

.login-dialog-prompt-layout {
  padding-top: 24px;
  padding-bottom: 12px;
  spacing: 8px;
  width: 27em;
}

.login-dialog-prompt-label {
  color: rgba(255, 255, 255, 0.5);
  font-size: 1em;
  padding-top: 1em;
}

.login-dialog-session-list-button StIcon {
  icon-size: 1.25em;
}

.login-dialog-session-list-button {
  color: rgba(255, 255, 255, 0.7);
}

.login-dialog-session-list-button:hover, .login-dialog-session-list-button:focus {
  color: #FFFFFF;
}

.login-dialog-session-list-button:active {
  color: #FFFFFF;
}

#LookingGlassDialog {
  background-color: #FFFFFF;
  spacing: 4px;
  padding: 0;
  border: none;
  border-radius: 2px;
  box-shadow: 0 10px 14px 5px rgba(0, 0, 0, 0.5), 0 10px 5px 5px rgba(0, 0, 0, 0.44);
}

#LookingGlassDialog > #Toolbar {
  padding: 0 8px;
  border: none;
  border-radius: 0;
  background-color: rgba(255, 255, 255, 0.01);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.1);
}

#LookingGlassDialog .labels {
  spacing: 0;
}

#LookingGlassDialog .notebook-tab {
  -natural-hpadding: 12px;
  -minimum-hpadding: 6px;
  font-weight: bold;
  color: rgba(87, 79, 74, 0.38);
  transition-duration: 0.15s;
  padding-left: 16px;
  padding-right: 16px;
  min-height: 36px;
  padding: 0 32px;
}

#LookingGlassDialog .notebook-tab:hover {
  box-shadow: inset 0 -2px 0px rgba(87, 79, 74, 0.26);
  color: rgba(87, 79, 74, 0.87);
  text-shadow: none;
}

#LookingGlassDialog .notebook-tab:selected {
  border-bottom-width: 0;
  border-color: transparent;
  background-color: rgba(255, 255, 255, 0.01);
  box-shadow: inset 0 -2px 0px #48b9c7;
  color: rgba(87, 79, 74, 0.87);
  text-shadow: none;
}

#LookingGlassDialog StBoxLayout#EvalBox {
  padding: 4px;
  spacing: 4px;
}

#LookingGlassDialog StBoxLayout#ResultsArea {
  spacing: 4px;
}

.lg-dialog StEntry {
  selection-background-color: #48b9c7;
  selected-color: #FFFFFF;
}

.lg-dialog .shell-link {
  color: #faa41a;
}

.lg-dialog .shell-link:hover {
  color: #faa41a;
}

.lg-completions-text {
  font-size: 1em;
  font-style: italic;
}

.lg-obj-inspector-title {
  spacing: 4px;
}

.lg-obj-inspector-button {
  min-height: 36px;
  padding: 0 16px;
  border: none;
  border-radius: 2px;
  font-size: 10.5pt;
  font-weight: 500;
  color: rgba(87, 79, 74, 0.75);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.lg-obj-inspector-button:hover {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(87, 79, 74, 0.12);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.lg-obj-inspector-button:active {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(87, 79, 74, 0.26);
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.lg-obj-inspector-button:insensitive {
  color: rgba(87, 79, 74, 0.26);
  background-color: transparent;
  border-color: transparent;
  box-shadow: 0 0 transparent;
  text-shadow: none;
  icon-shadow: none;
}

.lg-obj-inspector-button:focus {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(250, 164, 26, 0.3);
  text-shadow: none;
  icon-shadow: none;
  box-shadow: 0 0 transparent;
}

.lg-obj-inspector-button:hover {
  border: none;
}

#lookingGlassExtensions {
  padding: 4px;
}

.lg-extensions-list {
  padding: 4px;
  spacing: 6px;
}

.lg-extension {
  border: none;
  border-radius: 2px;
  padding: 4px;
}

.lg-extension-name {
  font-size: 18pt;
  font-weight: 400;
}

.lg-extension-meta {
  spacing: 6px;
}

#LookingGlassPropertyInspector {
  background: #FFFFFF;
  border: none;
  border-radius: 2px;
  padding: 6px;
  box-shadow: 0 10px 14px 5px rgba(0, 0, 0, 0.5), 0 10px 5px 5px rgba(0, 0, 0, 0.44);
}

/* Pocilloovers/Menus */
.popup-menu {
  min-width: 200px;
}

.popup-menu .popup-sub-menu {
  background-color: #FAFAFA;
  box-shadow: 0 0 transparent;
}

.popup-menu .popup-menu-content {
  padding: 8px 0;
}

.popup-menu .popup-menu-item {
  spacing: 8px;
  transition-duration: 0.1s;
}

.popup-menu .popup-menu-item:ltr {
  padding: 0.4em 24px 0.4em 0;
}

.popup-menu .popup-menu-item:rtl {
  padding: 0.4em 0 0.4em 24px;
}

.popup-menu .popup-menu-item:checked {
  background-color: #faa41a;
  color: #FFFFFF;
  box-shadow: 0 0 transparent;
  font-weight: normal;
}

.popup-menu .popup-menu-item:checked.selected {
  background-color: #fbb23c;
  color: #FFFFFF;
}

.popup-menu .popup-menu-item:checked:active {
  background-color: #fcbf5f;
  color: #FFFFFF !important;
}

.popup-menu .popup-menu-item:checked:insensitive {
  color: rgba(255, 255, 255, 0.5);
}

.popup-menu .popup-menu-item.selected {
  background-color: rgba(87, 79, 74, 0.12);
  color: rgba(87, 79, 74, 0.87);
  transition-duration: 0ms;
}

.popup-menu .popup-menu-item:active {
  background-color: rgba(87, 79, 74, 0.26);
  color: rgba(87, 79, 74, 0.87);
  transition-duration: 0.15s;
}

.popup-menu .popup-menu-item.selected:active {
  color: rgba(87, 79, 74, 0.87);
}

.popup-menu .popup-menu-item:insensitive {
  color: rgba(87, 79, 74, 0.38);
}

.popup-menu .popup-inactive-menu-item {
  color: rgba(87, 79, 74, 0.87);
}

.popup-menu .popup-inactive-menu-item:insensitive {
  color: rgba(87, 79, 74, 0.38);
}

.popup-menu.panel-menu {
  -boxpointer-gap: 4px;
  margin-bottom: 1.75em;
}

.popup-menu-ornament {
  text-align: right;
  width: 16px;
  height: 16px;
}

.popup-menu-boxpointer,
.candidate-popup-boxpointer {
  -arrow-border-radius: 0;
  -arrow-background-color: transparent;
  -arrow-border-width: 0;
  -arrow-border-color: transparent;
  -arrow-base: 0;
  -arrow-rise: 0;
  -arrow-box-shadow: none;
  margin: 5px 8px 8px;
  background-color: #FFFFFF;
  border-radius: 2px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.24), 0 3px 3px rgba(0, 0, 0, 0.345);
}

.popup-separator-menu-item {
  height: 1px;
  margin: 8px 40px;
  background-color: transparent;
  border-color: rgba(0, 0, 0, 0.1);
  border-bottom-width: 1px;
  border-bottom-style: solid;
}

.background-menu {
  -boxpointer-gap: 4px;
  -arrow-rise: 0;
}

/* fallback menu
- odd thing for styling App menu when apparently not running under shell. Light Adwaita styled
  app menu inside the main app window itself rather than the top bar
*/
/* links */
.shell-link {
  border-radius: 2px;
  color: #faa41a;
}

.shell-link:hover {
  color: #faa41a;
  background-color: rgba(250, 164, 26, 0.15);
}

.shell-link:active {
  color: #faa41a;
  background-color: rgba(250, 164, 26, 0.3);
}

.framed-user-icon {
  background-size: contain;
  border: none;
  color: #FFFFFF;
  border-radius: 2px;
}

.framed-user-icon:hover {
  border-color: #FFFFFF;
  color: #FFFFFF;
}

.magnifier-zoom-region {
  border: 2px solid #48b9c7;
}

.magnifier-zoom-region.full-screen {
  border-width: 0;
}

/* Modal Dialogs */
.headline {
  font-size: 15pt;
  font-weight: 500;
}

.lightbox {
  background-color: black;
}

.flashspot {
  background-color: white;
}

.modal-dialog {
  border-radius: 2px;
  color: rgba(87, 79, 74, 0.87);
  background-color: #FFFFFF;
  border: none;
  box-shadow: 0 10px 14px 5px rgba(0, 0, 0, 0.5), 0 10px 5px 5px rgba(0, 0, 0, 0.44);
}

.modal-dialog .modal-dialog-content-box {
  padding: 24px;
}

.modal-dialog .run-dialog-entry {
  width: 20em;
  margin-bottom: 6px;
}

.modal-dialog .run-dialog-error-box {
  padding-top: 16px;
  spacing: 6px;
}

.modal-dialog .run-dialog-button-box {
  padding-top: 1em;
}

.modal-dialog .run-dialog-label {
  font-size: 1em;
  font-weight: normal;
  color: rgba(87, 79, 74, 0.75);
  padding-bottom: .4em;
}

.mount-dialog-subject,
.end-session-dialog-subject {
  font-size: 15pt;
  font-weight: 500;
}

/* Message Dialog */
.message-dialog-main-layout {
  padding: 12px 20px 0;
  spacing: 12px;
}

.message-dialog-content {
  max-width: 28em;
  spacing: 20px;
}

.message-dialog-icon {
  min-width: 48px;
  icon-size: 48px;
}

.message-dialog-title {
  font-weight: bold;
}

.message-dialog-subtitle {
  color: rgba(87, 79, 74, 0.54);
  font-weight: bold;
}

/* End Session Dialog */
.end-session-dialog {
  spacing: 42px;
  border: none;
}

.end-session-dialog-list {
  padding-top: 20px;
}

.end-session-dialog-layout {
  padding-left: 17px;
}

.end-session-dialog-layout:rtl {
  padding-right: 17px;
}

.end-session-dialog-description {
  width: 28em;
  padding-bottom: 10px;
}

.end-session-dialog-description:rtl {
  text-align: right;
}

.end-session-dialog-warning {
  width: 28em;
  color: #ffce51;
  padding-top: 6px;
}

.end-session-dialog-warning:rtl {
  text-align: right;
}

.end-session-dialog-logout-icon {
  border-radius: 5px;
  width: 48px;
  height: 48px;
  background-size: contain;
}

.end-session-dialog-shutdown-icon {
  color: rgba(87, 79, 74, 0.38);
  width: 48px;
  height: 48px;
}

.end-session-dialog-inhibitor-layout {
  spacing: 16px;
  max-height: 200px;
  padding-right: 65px;
  padding-left: 65px;
}

.end-session-dialog-session-list,
.end-session-dialog-app-list {
  spacing: 1em;
}

.end-session-dialog-list-header {
  font-weight: bold;
}

.end-session-dialog-list-header:rtl {
  text-align: right;
}

.end-session-dialog-app-list-item,
.end-session-dialog-session-list-item {
  spacing: 1em;
}

.end-session-dialog-app-list-item-name,
.end-session-dialog-session-list-item-name {
  font-weight: bold;
}

.end-session-dialog-app-list-item-description {
  color: rgba(87, 79, 74, 0.38);
  font-size: 1em;
}

/* ShellMountOperation Dialogs */
.shell-mount-operation-icon {
  icon-size: 48px;
}

.mount-dialog {
  spacing: 24px;
}

.mount-dialog .message-dialog-title {
  padding-top: 10px;
  padding-left: 17px;
  padding-bottom: 6px;
  max-width: 34em;
}

.mount-dialog .message-dialog-title:rtl {
  padding-left: 0px;
  padding-right: 17px;
}

.mount-dialog .message-dialog-body {
  padding-left: 17px;
  width: 28em;
}

.mount-dialog .message-dialog-body:rtl {
  padding-left: 0px;
  padding-right: 17px;
}

.mount-dialog-app-list {
  max-height: 200px;
  padding-top: 24px;
  padding-left: 49px;
  padding-right: 32px;
}

.mount-dialog-app-list:rtl {
  padding-right: 49px;
  padding-left: 32px;
}

.mount-dialog-app-list-item {
  color: rgba(87, 79, 74, 0.87);
}

.mount-dialog-app-list-item:hover {
  color: rgba(87, 79, 74, 0.87);
}

.mount-dialog-app-list-item:ltr {
  padding-right: 1em;
}

.mount-dialog-app-list-item:rtl {
  padding-left: 1em;
}

.mount-dialog-app-list-item-icon:ltr {
  padding-right: 17px;
}

.mount-dialog-app-list-item-icon:rtl {
  padding-left: 17px;
}

.mount-dialog-app-list-item-name {
  font-size: 1em;
}

/* Password or Authentication Dialog */
.prompt-dialog {
  width: 34em;
  border: none;
}

.prompt-dialog .message-dialog-main-layout {
  spacing: 24px;
  padding: 10px;
}

.prompt-dialog .message-dialog-content {
  spacing: 16px;
}

.prompt-dialog .message-dialog-title {
  font-size: 15pt;
  font-weight: 500;
  color: rgba(87, 79, 74, 0.87);
}

.prompt-dialog-description:rtl {
  text-align: right;
}

.prompt-dialog-password-box {
  spacing: 1em;
  padding-bottom: 1em;
}

.prompt-dialog-error-label {
  font-size: 1em;
  color: #f15d22;
  padding-bottom: 8px;
}

.prompt-dialog-info-label {
  font-size: 1em;
  padding-bottom: 8px;
}

.hidden {
  color: transparent;
}

.prompt-dialog-null-label {
  font-size: 1em;
  padding-bottom: 8px;
}

/* Polkit Dialog */
.polkit-dialog-user-layout {
  padding-left: 10px;
  spacing: 10px;
}

.polkit-dialog-user-layout:rtl {
  padding-left: 0px;
  padding-right: 10px;
}

.polkit-dialog-user-root-label {
  color: #ffce51;
}

.polkit-dialog-user-icon {
  border-radius: 5px;
  background-size: contain;
  width: 48px;
  height: 48px;
}

/* Audio selection dialog */
.audio-device-selection-dialog {
  spacing: 30px;
}

.audio-selection-content {
  spacing: 20px;
  padding: 24px;
}

.audio-selection-title {
  font-weight: bold;
  text-align: center;
}

.audio-selection-box {
  spacing: 20px;
}

.audio-selection-device {
  border: 1px solid rgba(0, 0, 0, 0.1);
  border-radius: 2px;
}

.audio-selection-device:active, .audio-selection-device:hover, .audio-selection-device:focus {
  background-color: #48b9c7;
}

.audio-selection-device-box {
  padding: 20px;
  spacing: 20px;
}

.audio-selection-device-icon {
  icon-size: 64px;
}

/* Access Dialog */
.access-dialog {
  spacing: 30px;
}

/* Geolocation Dialog */
.geolocation-dialog {
  spacing: 30px;
}

/* Extension Dialog */
.extension-dialog .message-dialog-main-layout {
  spacing: 24px;
  padding: 10px;
}

.extension-dialog .message-dialog-title {
  color: rgba(87, 79, 74, 0.54);
}

/* Inhibit-Shortcuts Dialog */
.inhibit-shortcuts-dialog {
  spacing: 30px;
}

/* Network Agent Dialog */
.network-dialog-secret-table {
  spacing-rows: 15px;
  spacing-columns: 1em;
}

.keyring-dialog-control-table {
  spacing-rows: 15px;
  spacing-columns: 1em;
}

/* NETWORK DIALOGS */
.nm-dialog {
  max-height: 34em;
  min-height: 31em;
  min-width: 32em;
}

.nm-dialog-content {
  spacing: 20px;
  padding: 24px;
}

.nm-dialog-header-hbox {
  spacing: 10px;
}

.nm-dialog-airplane-box {
  spacing: 12px;
}

.nm-dialog-airplane-headline {
  font-weight: bold;
  text-align: center;
}

.nm-dialog-airplane-text {
  color: rgba(87, 79, 74, 0.87);
}

.nm-dialog-header-icon {
  icon-size: 32px;
}

.nm-dialog-scroll-view {
  border: none;
}

.nm-dialog-header {
  font-size: 15pt;
  font-weight: 500;
}

.nm-dialog-item {
  font-size: 1em;
  border-bottom: none;
  border-radius: 2px;
  padding: 12px;
  spacing: 20px;
}

.nm-dialog-item:hover, .nm-dialog-item:focus {
  background-color: rgba(87, 79, 74, 0.12);
}

.nm-dialog-item:active {
  background-color: rgba(87, 79, 74, 0.26);
}

.nm-dialog-item:selected {
  background-color: #48b9c7;
  color: #FFFFFF;
}

.nm-dialog-icons {
  spacing: .5em;
}

.nm-dialog-icon {
  icon-size: 16px;
}

.no-networks-label {
  color: rgba(87, 79, 74, 0.38);
}

.no-networks-box {
  spacing: 12px;
}

/* OSD */
.osd-window {
  text-align: center;
  font-weight: bold;
  spacing: 1em;
  margin: 32px;
  min-width: 64px;
  min-height: 64px;
}

.osd-window .osd-monitor-label {
  font-size: 45px;
  font-weight: 400;
}

.osd-window .level {
  height: 0.6em;
  border-radius: 4px;
  background-color: rgba(87, 79, 74, 0.12);
  color: rgba(87, 79, 74, 0.87);
}

.osd-window .level-bar {
  background-color: #48b9c7;
  border-radius: 2px;
}

/* Pad OSD */
.pad-osd-window {
  padding: 32px;
  background-color: #F5F5F5;
}

.pad-osd-window .pad-osd-title-box {
  spacing: 12px;
}

.pad-osd-window .pad-osd-title-menu-box {
  spacing: 6px;
}

.combo-box-label {
  width: 15em;
}

/* App Switcher */
.switcher-popup {
  padding: 8px;
  spacing: 16px;
}

.switcher-list-item-container {
  spacing: 8px;
}

.switcher-list .item-box {
  padding: 8px;
  border-radius: 2px;
}

.switcher-list .item-box:outlined {
  padding: 8px;
  border: none;
  background-color: rgba(87, 79, 74, 0.12);
}

.switcher-list .item-box:selected {
  background-color: #48b9c7;
  color: #FFFFFF;
}

.switcher-list .thumbnail-box {
  padding: 2px;
  spacing: 4px;
}

.switcher-list .thumbnail {
  width: 256px;
}

.switcher-list .separator {
  width: 1px;
  background: rgba(0, 0, 0, 0.1);
}

.switcher-arrow {
  border-color: transparent;
  color: rgba(87, 79, 74, 0.38);
}

.switcher-arrow:highlighted {
  color: rgba(87, 79, 74, 0.87);
}

.input-source-switcher-symbol {
  font-size: 45px;
  font-weight: 400;
  width: 96px;
  height: 96px;
}

/* Window Cycler */
.cycler-highlight {
  border: 4px solid #48b9c7;
}

/* Workspace Switcher */
.workspace-switcher-group {
  padding: 8px;
}

.workspace-switcher {
  background: transparent;
  border: 0px;
  border-radius: 0px;
  padding: 0px;
  spacing: 8px;
}

.ws-switcher-active-up, .ws-switcher-active-down {
  height: 48px;
  background-color: #48b9c7;
  color: #FFFFFF;
  background-size: 32px;
  border-radius: 2px;
}

.ws-switcher-box {
  height: 48px;
  border: none;
  background: rgba(87, 79, 74, 0.12);
  border-radius: 2px;
}

.osd-window,
.resize-popup,
.switcher-list, .workspace-switcher-container {
  color: rgba(87, 79, 74, 0.87);
  background-color: #FFFFFF;
  border: none;
  box-shadow: 0 10px 14px 5px rgba(0, 0, 0, 0.5), 0 10px 5px 5px rgba(0, 0, 0, 0.44);
  border-radius: 2px;
  padding: 12px;
}

/* Tiled window previews */
.tile-preview {
  background-color: rgba(228, 245, 247, 0.3);
  border: 1px solid #e4f5f7;
}

.tile-preview-left.on-primary {
  border-radius: 4px 4px 0 0;
}

.tile-preview-right.on-primary {
  border-radius: 0 4px 0 0;
}

.tile-preview-left.tile-preview-right.on-primary {
  border-radius: 4px 4px 0 0;
}

/* OVERVIEW */
#overview {
  spacing: 24px;
}

.overview-controls {
  padding-bottom: 32px;
}

.window-picker {
  -horizontal-spacing: 16px;
  -vertical-spacing: 16px;
  padding: 0 16px 16px;
}

.window-picker.external-monitor {
  padding: 16px;
}

.window-clone-border {
  border: 4px solid rgba(255, 255, 255, 0.3);
  border-radius: 2px;
  box-shadow: inset 0 0 0 1px rgba(255, 255, 255, 0.3);
}

.window-caption {
  spacing: 25px;
  color: #FFFFFF;
  background-color: #2e2927;
  border-radius: 2px;
  padding: 4px 8px;
}

.search-entry {
  width: 304px;
  padding: 0 8px;
  border-radius: 0;
  color: rgba(255, 255, 255, 0.5);
  selection-background-color: rgba(255, 255, 255, 0.3);
  selected-color: #FFFFFF;
  background-color: rgba(245, 245, 245, 0.01);
  border-color: transparent;
  box-shadow: inset 0 -1px rgba(255, 255, 255, 0.3);
}

.search-entry:focus {
  border-color: transparent;
  box-shadow: inset 0 -2px #faa41a;
  padding: 0 8px;
  border-width: 0;
  color: #FFFFFF;
}

.search-entry .search-entry-icon {
  icon-size: 16px;
  padding: 0 0;
  color: rgba(255, 255, 255, 0.5);
  transition: all 0.15s cubic-bezier(0, 0, 0.2, 1);
}

.search-entry:hover .search-entry-icon, .search-entry:focus .search-entry-icon {
  color: #FFFFFF;
}

#searchResultsBin {
  max-width: 1000px;
}

#searchResultsContent {
  padding-left: 20px;
  padding-right: 20px;
  spacing: 16px;
}

.search-section {
  spacing: 16px;
}

.search-section-content {
  spacing: 32px;
}

.list-search-results {
  spacing: 3px;
}

.search-section-separator {
  height: 1px;
  background-color: rgba(255, 255, 255, 0.12);
}

.list-search-result-content {
  spacing: 30px;
}

.list-search-result-title {
  font-size: 12pt;
  font-weight: 400;
  color: #FFFFFF;
  spacing: 12px;
}

.list-search-result-description {
  color: rgba(255, 255, 255, 0.7);
}

.list-search-provider-details {
  width: 150px;
  color: rgba(255, 255, 255, 0.7);
  margin-top: 0.24em;
}

.list-search-provider-content {
  spacing: 20px;
}

.search-provider-icon {
  padding: 15px;
}

/* DASHBOARD */
#dash {
  font-size: 1em;
  color: #FFFFFF;
  background-color: rgba(37, 34, 32, 0.5);
  padding: 3px 0;
  border: none;
  border-left: 0px;
  border-radius: 0px 4px 4px 0px;
}

#dash:rtl {
  border-radius: 4px 0 0 4px;
}

#dash .placeholder {
  background-image: url("assets/dash-placeholder.svg");
  background-size: contain;
  height: 24px;
}

#dash .empty-dash-drop-target {
  width: 24px;
  height: 24px;
}

.dash-item-container > StWidget {
  padding: 3px 6px;
}

.dash-label {
  border-radius: 2px;
  padding: 7px 8px;
  color: rgba(87, 79, 74, 0.87);
  background-color: #FFFFFF;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.24), 0 3px 3px rgba(0, 0, 0, 0.345);
  text-align: center;
  -x-offset: 8px;
}

/* App Vault/Grid */
.icon-grid {
  spacing: 30px;
  -shell-grid-horizontal-item-size: 136px;
  -shell-grid-vertical-item-size: 136px;
}

.icon-grid .overview-icon {
  icon-size: 96px;
}

.system-action-icon {
  box-shadow: 0 4px 4px rgba(0, 0, 0, 0.2);
  background-color: #212121;
  color: #FFFFFF;
  border-radius: 99px;
  icon-size: 48px;
}

.app-view-controls {
  width: 320px;
  padding-bottom: 32px;
}

.app-view-control {
  padding: 0 16px;
  font-weight: bold;
  color: rgba(255, 255, 255, 0.7);
}

.app-view-control:hover {
  color: #FFFFFF;
  background-color: rgba(255, 255, 255, 0.12) !important;
}

.app-view-control:active {
  color: #FFFFFF;
  background-color: rgba(255, 255, 255, 0.3) !important;
}

.app-view-control:checked {
  color: #FFFFFF;
  background-color: rgba(245, 245, 245, 0.01) !important;
  box-shadow: inset 0 2px 0 #faa41a;
}

.app-view-control:first-child {
  border-right-width: 0;
  border-radius: 2px;
}

.app-view-control:first-child:checked {
  border-radius: 0;
}

.app-view-control:last-child {
  border-radius: 2px;
}

.app-view-control:last-child:checked {
  border-radius: 0;
}

.search-provider-icon:focus, .search-provider-icon:selected, .search-provider-icon:hover,
.list-search-result:focus,
.list-search-result:selected,
.list-search-result:hover {
  background-color: rgba(255, 255, 255, 0.2);
  transition-duration: 0ms;
}

.search-provider-icon:active, .search-provider-icon:checked,
.list-search-result:active,
.list-search-result:checked {
  background-color: rgba(255, 255, 255, 0.2);
  transition-duration: 0.15s;
}

.app-well-app:hover .overview-icon,
.app-well-app:focus .overview-icon,
.app-well-app:selected .overview-icon,
.app-well-app.app-folder:hover .overview-icon,
.app-well-app.app-folder:focus .overview-icon,
.app-well-app.app-folder:selected .overview-icon,
.show-apps:hover .overview-icon,
.show-apps:focus .overview-icon,
.show-apps:selected .overview-icon,
.grid-search-result:hover .overview-icon,
.grid-search-result:focus .overview-icon,
.grid-search-result:selected .overview-icon {
  background-color: rgba(255, 255, 255, 0.2);
  transition-duration: 0ms;
  border-image: none;
  background-image: none;
}

.app-well-app:active .overview-icon,
.app-well-app:checked .overview-icon,
.app-well-app.app-folder:active .overview-icon,
.app-well-app.app-folder:checked .overview-icon,
.show-apps:active .overview-icon,
.show-apps:checked .overview-icon,
.grid-search-result:active .overview-icon,
.grid-search-result:checked .overview-icon {
  background-color: rgba(255, 255, 255, 0.2);
  box-shadow: 0 0 transparent;
  transition-duration: 0.15s;
}

.app-well-app-running-dot {
  width: 32px;
  height: 2px;
  background-color: #faa41a;
  margin-bottom: 0;
}

.search-provider-icon,
.list-search-result, .app-well-app .overview-icon,
.app-well-app.app-folder .overview-icon,
.show-apps .overview-icon,
.grid-search-result .overview-icon {
  color: #FFFFFF;
  background-color: transparent;
  border-radius: 2px;
  padding: 6px;
  border: none;
  transition-duration: 0.15s;
  text-align: center;
}

.app-well-app.app-folder > .overview-icon {
  background-color: rgba(255, 255, 255, 0.2);
}

.show-apps .show-apps-icon {
  color: rgba(255, 255, 255, 0.7);
}

.show-apps:hover .show-apps-icon,
.show-apps:active .show-apps-icon,
.show-apps:checked .show-apps-icon,
.show-apps:focus .show-apps-icon {
  color: #FFFFFF;
  transition-duration: 0.15s;
}

.app-folder-popup {
  -arrow-border-radius: 2px;
  -arrow-background-color: rgba(255, 255, 255, 0.2);
  -arrow-base: 24px;
  -arrow-rise: 12px;
}

.app-folder-popup-bin {
  padding: 5px;
}

.app-folder-icon {
  padding: 5px;
  spacing-rows: 5px;
  spacing-columns: 5px;
}

.page-indicator {
  padding: 15px 20px;
}

.page-indicator .page-indicator-icon {
  width: 12px;
  height: 12px;
  border-radius: 12px;
  background-image: none;
  background-color: rgba(255, 255, 255, 0.3);
}

.page-indicator:hover .page-indicator-icon {
  background-image: none;
  background-color: rgba(255, 255, 255, 0.5);
}

.page-indicator:active .page-indicator-icon {
  background-image: none;
  background-color: rgba(255, 255, 255, 0.7);
}

.page-indicator:checked .page-indicator-icon {
  background-image: none;
  background-color: #FFFFFF;
  transition-duration: 0ms;
}

.page-indicator:checked:active {
  background-image: none;
}

.app-well-app > .overview-icon.overview-icon-with-label,
.grid-search-result .overview-icon.overview-icon-with-label {
  padding: 10px 8px 5px 8px;
  spacing: 4px;
}

.workspace-thumbnails {
  background-color: transparent !important;
  visible-width: 32px;
  spacing: 12px;
  padding: 12px;
  border-radius: 2px 0 0 2px;
}

.workspace-thumbnails:rtl {
  border-radius: 0 2px 2px 0;
}

.workspace-thumbnail-indicator {
  border: 0 solid #faa41a;
  border-left-width: 2px;
  padding: 6px;
  border-radius: 0;
}

.search-display > StBoxLayout,
.all-apps,
.frequent-apps > StBoxLayout {
  padding: 0px 88px 10px 88px;
}

.workspace-thumbnails {
  color: #FFFFFF;
  background-color: transparent;
  border: none;
}

.search-statustext, .no-frequent-applications-label {
  font-size: 45px;
  font-weight: 400;
  color: rgba(255, 255, 255, 0.5);
}

/* Scrollbars */
StScrollView.vfade {
  -st-vfade-offset: 32px;
}

StScrollView.hfade {
  -st-hfade-offset: 32px;
}

StScrollBar {
  padding: 0;
}

StScrollView StScrollBar {
  min-width: 16px;
  min-height: 16px;
}

StScrollBar StBin#trough {
  margin: 4px;
  border-radius: 100px;
  background-color: rgba(87, 79, 74, 0.12);
}

StScrollBar StButton#vhandle, StScrollBar StButton#hhandle {
  border-radius: 100px;
  background-color: rgba(87, 79, 74, 0.38);
  margin: 4px;
}

StScrollBar StButton#vhandle:hover, StScrollBar StButton#hhandle:hover {
  background-color: rgba(87, 79, 74, 0.54);
}

StScrollBar StButton#vhandle:active, StScrollBar StButton#hhandle:active {
  background-color: rgba(87, 79, 74, 0.87);
}

#screenShieldNotifications StScrollBar StBin#trough, #overview StScrollBar StBin#trough {
  background-color: rgba(255, 255, 255, 0.12);
}

#screenShieldNotifications StScrollBar StButton#vhandle, #overview StScrollBar StButton#vhandle, #screenShieldNotifications StScrollBar StButton#hhandle, #overview StScrollBar StButton#hhandle {
  background-color: rgba(255, 255, 255, 0.5);
}

#screenShieldNotifications StScrollBar StButton#vhandle:hover, #overview StScrollBar StButton#vhandle:hover, #screenShieldNotifications StScrollBar StButton#hhandle:hover, #overview StScrollBar StButton#hhandle:hover {
  background-color: rgba(255, 255, 255, 0.7);
}

#screenShieldNotifications StScrollBar StButton#vhandle:active, #overview StScrollBar StButton#vhandle:active, #screenShieldNotifications StScrollBar StButton#hhandle:active, #overview StScrollBar StButton#hhandle:active {
  background-color: #FFFFFF;
}

/* Slider */
.slider {
  height: 20px;
  color: #48b9c7;
  -slider-height: 2px;
  -slider-background-color: rgba(87, 79, 74, 0.26);
  -slider-border-color: transparent;
  -slider-active-background-color: #48b9c7;
  -slider-active-border-color: transparent;
  -slider-border-width: 0;
  -slider-handle-radius: 7px;
}

/* Switches */
.toggle-switch {
  width: 40px;
  height: 20px;
  background-size: contain;
}

.toggle-switch-us {
  background-image: url("assets/toggle-off.svg");
}

.toggle-switch-us:checked {
  background-image: url("assets/toggle-on.svg");
}

.toggle-switch-intl {
  background-image: url("assets/toggle-off.svg");
}

.toggle-switch-intl:checked {
  background-image: url("assets/toggle-on.svg");
}

/* TOP BAR */
#panel {
  background-color: #252220;
  /* transition from solid to transparent */
  transition-duration: 250ms;
  font-weight: bold;
  height: 2.28571em;
  min-height: 24px;
  max-height: 32px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.24), 0 3px 3px rgba(0, 0, 0, 0.345);
}

#panel.solid {
  box-shadow: none;
}

#panel.unlock-screen, #panel.login-screen, #panel.lock-screen {
  background-color: rgba(37, 34, 32, 0.5);
  border: none;
  box-shadow: none;
}

#panel #panelLeft, #panel #panelCenter {
  spacing: 0;
}

#panel .panel-corner {
  -panel-corner-radius: 6px;
  -panel-corner-background-color: #252220;
  -panel-corner-border-width: 0;
  -panel-corner-border-color: transparent;
}

#panel .panel-corner:active, #panel .panel-corner:overview, #panel .panel-corner:focus {
  -panel-corner-border-color: #faa41a;
}

#panel .panel-corner.lock-screen, #panel .panel-corner.login-screen, #panel .panel-corner.unlock-screen {
  -panel-corner-radius: 0;
  -panel-corner-background-color: transparent;
  -panel-corner-border-color: transparent;
}

#panel .panel-button {
  -natural-hpadding: 12px;
  -minimum-hpadding: 6px;
  font-weight: bold;
  color: rgba(255, 255, 255, 0.7);
  text-shadow: none;
  transition-duration: 0.15s;
}

#panel .panel-button .app-menu-icon {
  -st-icon-style: symbolic;
  margin-left: 4px;
  margin-right: 4px;
}

#panel .panel-button .system-status-icon,
#panel .panel-button .app-menu-icon > StIcon,
#panel .panel-button .popup-menu-arrow {
  icon-shadow: none;
}

#panel .panel-button:hover {
  color: #FFFFFF;
  text-shadow: none;
}

#panel .panel-button:hover .system-status-icon,
#panel .panel-button:hover .app-menu-icon > StIcon,
#panel .panel-button:hover .popup-menu-arrow {
  icon-shadow: none;
}

#panel .panel-button:active, #panel .panel-button:overview, #panel .panel-button:focus, #panel .panel-button:checked {
  background-color: rgba(245, 245, 245, 0.01);
  box-shadow: inset 0 -2px 0px #faa41a;
  color: #FFFFFF;
}

#panel .panel-button:active > .system-status-icon, #panel .panel-button:overview > .system-status-icon, #panel .panel-button:focus > .system-status-icon, #panel .panel-button:checked > .system-status-icon {
  icon-shadow: none;
}

#panel .panel-button .system-status-icon {
  icon-size: 1.14286em;
  padding: 0 4px;
}

.unlock-screen #panel .panel-button,
.login-screen #panel .panel-button,
.lock-screen #panel .panel-button {
  color: rgba(255, 255, 255, 0.7);
}

.unlock-screen #panel .panel-button:focus, .unlock-screen #panel .panel-button:hover, .unlock-screen #panel .panel-button:active,
.login-screen #panel .panel-button:focus,
.login-screen #panel .panel-button:hover,
.login-screen #panel .panel-button:active,
.lock-screen #panel .panel-button:focus,
.lock-screen #panel .panel-button:hover,
.lock-screen #panel .panel-button:active {
  color: #FFFFFF;
}

#panel .panel-status-indicators-box,
#panel .panel-status-menu-box {
  spacing: 2px;
}

#panel .power-status.panel-status-indicators-box {
  spacing: 0;
}

#panel .screencast-indicator {
  color: #ffce51;
}

#panel.solid {
  background-color: #252220;
  /* transition from transparent to solid */
  transition-duration: 250ms;
}

#panel.solid .panel-corner {
  -panel-corner-background-color: #252220;
}

#panel.solid .panel-button {
  color: rgba(255, 255, 255, 0.7);
  text-shadow: none;
}

#panel.solid .panel-button:hover {
  color: #FFFFFF;
}

#panel.solid .system-status-icon,
#panel.solid .app-menu-icon > StIcon,
#panel.solid .popup-menu-arrow {
  icon-shadow: none;
}

#calendarArea {
  padding: 8px 16px;
}

.calendar {
  margin-bottom: 0;
}

.calendar,
.datemenu-today-button,
.datemenu-displays-box,
.message-list-sections {
  margin: 0 8px;
}

.datemenu-calendar-column {
  spacing: 8px;
}

.datemenu-displays-section {
  padding-bottom: 0;
}

.datemenu-displays-box {
  spacing: 8px;
}

.datemenu-calendar-column {
  border: 0 solid rgba(0, 0, 0, 0.1);
}

.datemenu-calendar-column:ltr {
  border-left-width: 0;
}

.datemenu-calendar-column:rtl {
  border-right-width: 0;
}

.datemenu-today-button,
.world-clocks-button,
.weather-button,
.events-section-title {
  min-height: 24px;
  padding: 4px 8px;
  border-radius: 2px;
}

.datemenu-today-button {
  min-height: 56px;
}

.message-list-section-list:ltr {
  padding-left: 0;
}

.message-list-section-list:rtl {
  padding-right: 0;
}

.datemenu-today-button:hover, .datemenu-today-button:focus,
.world-clocks-button:hover,
.world-clocks-button:focus,
.weather-button:hover,
.weather-button:focus,
.events-section-title:hover,
.events-section-title:focus {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(87, 79, 74, 0.12);
}

.datemenu-today-button:active,
.world-clocks-button:active,
.weather-button:active,
.events-section-title:active {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(87, 79, 74, 0.26);
}

.datemenu-today-button .date-label {
  font-size: 18pt;
  font-weight: 400;
}

.world-clocks-header,
.weather-header,
.events-section-title {
  color: rgba(87, 79, 74, 0.54);
  font-weight: bold;
}

.world-clocks-grid {
  spacing-rows: 0.4em;
}

.weather-box {
  spacing: 0.4em;
}

.calendar-month-label {
  height: 20px;
  margin: 2px;
  padding: 6px 16px;
  border-radius: 2px;
  color: rgba(87, 79, 74, 0.87);
  font-weight: bold;
  text-align: center;
}

.calendar-month-label:focus {
  background-color: rgba(87, 79, 74, 0.12);
}

.pager-button {
  width: 32px;
  height: 32px;
  margin: 2px;
  border-radius: 100px;
  background-color: transparent;
  color: rgba(87, 79, 74, 0.87);
}

.pager-button:hover, .pager-button:focus {
  background-color: rgba(87, 79, 74, 0.12);
}

.pager-button:active {
  background-color: rgba(87, 79, 74, 0.26);
}

.calendar-change-month-back {
  background-image: url("assets/calendar-arrow-left.svg");
}

.calendar-change-month-back:rtl {
  background-image: url("assets/calendar-arrow-right.svg");
}

.calendar-change-month-forward {
  background-image: url("assets/calendar-arrow-right.svg");
}

.calendar-change-month-forward:rtl {
  background-image: url("assets/calendar-arrow-left.svg");
}

.calendar-day-base {
  font-size: 9pt;
  font-weight: 400;
  text-align: center;
  width: 32px;
  height: 32px;
  padding: 0;
  margin: 2px;
  border-radius: 100px;
}

.calendar-day-base:hover, .calendar-day-base:focus {
  background-color: rgba(87, 79, 74, 0.12);
}

.calendar-day-base:active {
  color: inherit;
  background-color: rgba(87, 79, 74, 0.26);
  border-color: transparent;
}

.calendar-day-base:selected {
  color: #FFFFFF;
  background-color: #faa41a;
  border-color: transparent;
}

.calendar-day-base.calendar-day-heading {
  width: 32px;
  height: 25px;
  margin-top: 2px;
  padding: 7px 0 0;
  border-radius: 100px;
  background-color: transparent;
  color: rgba(87, 79, 74, 0.38);
  font-size: 9pt;
  font-weight: 400;
  font-weight: bold;
  text-align: center;
}

.calendar-day {
  border-width: 0;
}

.calendar-day-top {
  border-top-width: 0;
}

.calendar-day-left {
  border-left-width: 0;
}

.calendar-nonwork-day {
  color: rgba(87, 79, 74, 0.87);
}

.calendar-today {
  font-weight: bold !important;
  border: none;
}

.calendar-day-with-events {
  color: #48b9c7;
  font-weight: normal;
  text-decoration: underline;
  background-image: none;
}

.calendar-other-month-day {
  color: rgba(87, 79, 74, 0.26);
  opacity: 0.5;
}

.calendar-week-number {
  width: 32px;
  height: 25px;
  margin: 2px;
  padding: 7px 0 0;
  border-radius: 100px;
  background-color: transparent;
  color: rgba(87, 79, 74, 0.38);
  font-size: inherit;
  font-weight: bold;
  text-align: center;
}

/* Message list */
.message-list {
  width: 420px;
}

.message-list-clear-button.button {
  background-color: transparent;
  margin: 8px 8px 0;
}

.message-list-clear-button.button:hover, .message-list-clear-button.button:focus {
  background-color: rgba(87, 79, 74, 0.12);
}

.message-list-clear-button.button:active {
  background-color: rgba(87, 79, 74, 0.26);
}

.message-list-sections {
  spacing: 8px;
}

.message-list-section,
.message-list-section-list {
  spacing: 8px;
}

.message {
  min-height: 64px;
  background-color: transparent;
  border-radius: 2px;
}

.message:hover, .message:focus {
  background-color: rgba(87, 79, 74, 0.12);
}

.message:active {
  background-color: rgba(87, 79, 74, 0.26);
}

.message-icon-bin {
  padding: 8px 0px 8px 8px;
}

.message-icon-bin:rtl {
  padding: 8px 8px 8px 0px;
}

.message-icon-bin > StIcon {
  color: rgba(87, 79, 74, 0.87);
  icon-size: 16px;
  -st-icon-style: requested;
  margin: 4px 0px 4px 4px;
}

.message-icon-bin > StIcon:rtl {
  margin: 4px 4px 4px 0px;
}

.message-secondary-bin {
  padding: 0 8px;
}

.message-secondary-bin > .event-time {
  min-height: 22px;
  padding-top: 2px;
  color: rgba(87, 79, 74, 0.54);
  font-size: 1em;
  padding-bottom: 0;
}

.message-secondary-bin > StIcon {
  icon-size: 16px;
}

.message-title {
  min-height: 22px;
  padding-top: 2px;
  color: rgba(87, 79, 74, 0.87);
  font-weight: bold;
  font-size: 1em;
}

.message-content {
  min-height: 48px;
  padding: 8px;
  color: rgba(87, 79, 74, 0.54);
  font-size: 1em;
}

.message-content * > StIcon {
  icon-size: 16px;
  border-radius: 16px;
  padding: 4px;
  color: rgba(87, 79, 74, 0.54);
}

.message-content *:hover > StIcon,
.message-content *:focus > StIcon {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(87, 79, 74, 0.12);
}

.message-content *:active > StIcon {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(87, 79, 74, 0.26);
}

.message-media-control {
  margin: 16px 0;
  padding: 8px;
  border-radius: 100px;
  color: rgba(87, 79, 74, 0.54);
}

.message-media-control:hover, .message-media-control:focus {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(87, 79, 74, 0.12);
}

.message-media-control:active {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(87, 79, 74, 0.26);
}

.message-media-control:insensitive {
  color: rgba(87, 79, 74, 0.26);
}

.message-media-control:last-child:ltr {
  margin-right: 16px;
  padding-right: 8px;
}

.message-media-control:last-child:rtl {
  margin-left: 16px;
  padding-left: 8px;
}

.media-message-cover-icon {
  icon-size: 32px !important;
  margin: 8px 0px 8px 4px !important;
}

.media-message-cover-icon:rtl {
  margin: 8px 4px 8px 0px !important;
}

.media-message-cover-icon.fallback {
  icon-size: 16px !important;
  padding: 8px;
  border: none;
  border-radius: 2px;
  background-color: rgba(87, 79, 74, 0.12);
  color: rgba(87, 79, 74, 0.38);
}

.system-switch-user-submenu-icon.user-icon {
  icon-size: 20px;
  padding: 0 2px;
}

.system-switch-user-submenu-icon.default-icon {
  icon-size: 16px;
  padding: 0 4px;
}

#appMenu {
  spinner-image: url("process-working.svg");
  spacing: 4px;
}

#appMenu .label-shadow {
  color: transparent;
}

.aggregate-menu {
  min-width: 280px;
}

.aggregate-menu .popup-menu-icon {
  padding: 0 4px;
}

.system-menu-action {
  color: rgba(87, 79, 74, 0.54);
  border-radius: 100px;
  /* wish we could do 50% */
  padding: 16px;
  border: none;
}

.system-menu-action:hover, .system-menu-action:focus {
  background-color: rgba(87, 79, 74, 0.12);
  color: rgba(87, 79, 74, 0.87);
  border: none;
  padding: 16px;
}

.system-menu-action:active {
  background-color: rgba(87, 79, 74, 0.26);
  color: rgba(87, 79, 74, 0.87);
}

.system-menu-action > StIcon {
  icon-size: 16px;
}

.ripple-box {
  width: 48px;
  height: 48px;
  background-image: url("assets/corner-ripple-ltr.svg");
  background-size: contain;
}

.ripple-box:rtl {
  background-image: url("assets/corner-ripple-rtl.svg");
}

.popup-menu-arrow {
  width: 16px;
  height: 16px;
}

.popup-menu-icon {
  icon-size: 1.14286em;
}

.window-close {
  transition-duration: 0ms;
  height: 36px;
  width: 36px;
  -shell-close-overlap: 18px;
  -st-background-image-shadow: 0 1px 1.5px rgba(0, 0, 0, 0.12), 0 1px 1px rgba(0, 0, 0, 0.24);
  background-image: url("assets/window-close.svg");
  background-size: 36px;
}

.window-close:hover {
  -st-background-image-shadow: 0 3px 3px rgba(0, 0, 0, 0.24), 0 3px 3px rgba(0, 0, 0, 0.345);
  background-image: url("assets/window-close.svg");
}

.window-close:active {
  background-image: url("assets/window-close-active.svg");
}

.window-close:rtl {
  -st-background-image-shadow: 0 1px 1.5px rgba(0, 0, 0, 0.12), 0 1px 1px rgba(0, 0, 0, 0.24);
}

.window-close:rtl:hover {
  -st-background-image-shadow: 0 3px 3px rgba(0, 0, 0, 0.24), 0 3px 3px rgba(0, 0, 0, 0.345);
}

/* On-screen Keyboard */
#keyboard {
  background-color: #2e2927;
}

.keyboard-layout {
  spacing: 10px;
  padding: 10px;
}

.keyboard-row {
  spacing: 15px;
}

.keyboard-key {
  min-height: 72px;
  min-width: 72px;
  font-size: 2em;
  font-weight: 500;
  border-radius: 2px;
  border: none;
  color: inherit;
  color: rgba(87, 79, 74, 0.75);
  background-color: #FFFFFF;
  border-color: transparent;
  box-shadow: 0 1px 1.5px rgba(0, 0, 0, 0.12), 0 1px 1px rgba(0, 0, 0, 0.24);
  text-shadow: none;
  icon-shadow: none;
}

.keyboard-key:focus {
  color: rgba(87, 79, 74, 0.87);
  text-shadow: none;
  icon-shadow: none;
  box-shadow: 0 0 transparent;
}

.keyboard-key:hover, .keyboard-key:checked {
  color: rgba(87, 79, 74, 0.87);
  background-color: #FFFFFF;
  border-color: transparent;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.24), 0 3px 3px rgba(0, 0, 0, 0.345);
  text-shadow: none;
  icon-shadow: none;
}

.keyboard-key:active {
  color: rgba(87, 79, 74, 0.87);
  background-color: rgba(213, 211, 210, 0.961);
  border-color: transparent;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.24), 0 3px 3px rgba(0, 0, 0, 0.345);
  text-shadow: none;
  icon-shadow: none;
}

.keyboard-key:grayed {
  background-color: #2e2927;
  color: #FFFFFF;
  border-color: #2e2927;
}

.keyboard-subkeys {
  color: inherit;
  padding: 5px;
  -arrow-border-radius: 0;
  -arrow-background-color: transparent;
  -arrow-border-width: 0;
  -arrow-border-color: transparent;
  -arrow-base: 0;
  -arrow-rise: 0;
  -boxpointer-gap: 5px;
  background-color: #FFFFFF;
  border-radius: 2px;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.24), 0 3px 3px rgba(0, 0, 0, 0.345);
}

/* NOTIFICATIONS & MESSAGE TRAY */
.url-highlighter {
  link-color: #faa41a;
}

.notification-banner {
  font-size: 1em;
  width: 34em;
  min-height: 64px;
  margin: 5px;
  border-radius: 2px;
  color: rgba(87, 79, 74, 0.87);
  background-color: #F5F5F5;
  border: none;
  box-shadow: 0 3px 3px rgba(0, 0, 0, 0.24), 0 3px 3px rgba(0, 0, 0, 0.345);
}

.notification-banner:hover {
  background-color: #F5F5F5;
}

.notification-banner:focus {
  background-color: #F5F5F5;
}

.notification-banner .notification-icon {
  padding: 5px;
}

.notification-banner .notification-content {
  padding: 5px;
  spacing: 5px;
}

.notification-banner .secondary-icon {
  icon-size: 1.14286em;
}

.notification-banner .notification-actions {
  background-color: #F5F5F5;
  padding-top: 0;
  border-top: 1px solid rgba(0, 0, 0, 0.1);
  spacing: 1px;
}

.notification-banner .notification-button {
  min-height: 40px;
  padding: 0 16px;
  background-color: #F5F5F5;
  color: rgba(87, 79, 74, 0.54);
  font-weight: 500;
}

.notification-banner .notification-button:first-child {
  border-radius: 0 0 0 2px;
}

.notification-banner .notification-button:last-child {
  border-radius: 0 0 2px 0;
}

.notification-banner .notification-button:hover, .notification-banner .notification-buttonfocus {
  background-color: rgba(87, 79, 74, 0.12);
  color: rgba(87, 79, 74, 0.87);
}

.notification-banner .notification-button:active {
  background-color: rgba(87, 79, 74, 0.26);
  color: rgba(87, 79, 74, 0.87);
}

.summary-source-counter {
  font-size: 1em;
  font-weight: bold;
  height: 1.6em;
  width: 1.6em;
  -shell-counter-overlap-x: 3px;
  -shell-counter-overlap-y: 3px;
  background-color: #48b9c7;
  color: #FFFFFF;
  border: 2px solid #FFFFFF;
  box-shadow: 0 2px 2px rgba(0, 0, 0, 0.5);
  border-radius: 0.9em;
}

.secondary-icon {
  icon-size: 1.14286em;
}

.chat-body {
  spacing: 5px;
}

.chat-response {
  margin: 5px;
}

.chat-log-message {
  color: rgba(87, 79, 74, 0.87);
}

.chat-new-group {
  padding-top: 1em;
}

.chat-received {
  padding-left: 4px;
}

.chat-received:rtl {
  padding-left: 0px;
  padding-right: 4px;
}

.chat-sent {
  padding-left: 18pt;
  color: rgba(87, 79, 74, 0.54);
}

.chat-sent:rtl {
  padding-left: 0;
  padding-right: 18pt;
}

.chat-meta-message {
  padding-left: 4px;
  font-size: 9pt;
  font-weight: 400;
  color: rgba(87, 79, 74, 0.38);
}

.chat-meta-message:rtl {
  padding-left: 0;
  padding-right: 4px;
}

.hotplug-transient-box {
  spacing: 6px;
  padding: 2px 72px 2px 12px;
}

.hotplug-notification-item {
  padding: 2px 10px;
}

.hotplug-notification-item:focus {
  padding: 1px 71px 1px 11px;
}

.hotplug-notification-item-icon {
  icon-size: 24px;
  padding: 2px 5px;
}

.hotplug-resident-box {
  spacing: 8px;
}

.hotplug-resident-mount {
  spacing: 8px;
  border-radius: 2px;
}

.hotplug-resident-mount:hover {
  background-color: rgba(87, 79, 74, 0.12);
}

.hotplug-resident-mount:active {
  background-color: rgba(87, 79, 74, 0.26);
}

.hotplug-resident-mount-label {
  color: inherit;
  padding-left: 6px;
}

.hotplug-resident-mount-icon {
  icon-size: 24px;
  padding-left: 6px;
}

.hotplug-resident-eject-icon {
  icon-size: 16px;
}

.hotplug-resident-eject-button {
  padding: 7px;
  border-radius: 2px;
  color: rgba(87, 79, 74, 0.87);
}

/* Dash to Dock */
#dashtodockContainer #dash {
  background-color: rgba(37, 34, 32, 0.85);
}

#dashtodockContainer:overview #dash {
  background-color: rgba(37, 34, 32, 0.85);
}

#dashtodockContainer.extended:overview #dash {
  background-color: transparent;
}

#dashtodockContainer.left #dash,
#dashtodockContainer.right #dash {
  padding: 3px 0;
}

#dashtodockContainer.top #dash,
#dashtodockContainer.bottom #dash {
  padding: 0 3px;
}

#dashtodockContainer.extended #dash {
  padding: 0;
  border-radius: 0;
}

#dashtodockContainer.left .dash-item-container > StWidget,
#dashtodockContainer.right .dash-item-container > StWidget,
#dashtodockContainer.extended.left .dash-item-container > StWidget,
#dashtodockContainer.extended.right .dash-item-container > StWidget {
  padding: 3px 6px;
}

#dashtodockContainer.extended.left .dash-item-container:first-child > StWidget,
#dashtodockContainer.extended.right .dash-item-container:first-child > StWidget {
  padding: 6px 6px 3px 6px;
}

#dashtodockContainer.extended.left .dash-item-container:last-child > StWidget,
#dashtodockContainer.extended.right .dash-item-container:last-child > StWidget {
  padding: 3px 6px 6px 6px;
}

#dashtodockContainer.top .dash-item-container > StWidget,
#dashtodockContainer.bottom .dash-item-container > StWidget,
#dashtodockContainer.extended.top .dash-item-container > StWidget,
#dashtodockContainer.extended.bottom .dash-item-container > StWidget {
  padding: 6px 3px;
}

#dashtodockContainer.extended.top .dash-item-container:first-child > StWidget,
#dashtodockContainer.extended.bottom .dash-item-container:first-child > StWidget {
  padding: 6px 3px 6px 6px;
}

#dashtodockContainer.extended.top .dash-item-container:last-child > StWidget,
#dashtodockContainer.extended.bottom .dash-item-container:last-child > StWidget {
  padding: 6px 6px 6px 3px;
}

#dashtodockContainer .app-well-app-running-dot {
  background-color: transparent;
}

#dashtodockContainer .dash-item-container > StWidget {
  background-size: cover;
}

#dashtodockContainer.left .dash-item-container > StWidget.running1 {
  background-image: url("assets/dash/left-running1.svg");
}

#dashtodockContainer.left .dash-item-container > StWidget.running1.focused {
  background-image: url("assets/dash/left-running1-focused.svg");
}

#dashtodockContainer.left .dash-item-container > StWidget.running2 {
  background-image: url("assets/dash/left-running2.svg");
}

#dashtodockContainer.left .dash-item-container > StWidget.running2.focused {
  background-image: url("assets/dash/left-running2-focused.svg");
}

#dashtodockContainer.left .dash-item-container > StWidget.running3 {
  background-image: url("assets/dash/left-running3.svg");
}

#dashtodockContainer.left .dash-item-container > StWidget.running3.focused {
  background-image: url("assets/dash/left-running3-focused.svg");
}

#dashtodockContainer.left .dash-item-container > StWidget.running4 {
  background-image: url("assets/dash/left-running4.svg");
}

#dashtodockContainer.left .dash-item-container > StWidget.running4.focused {
  background-image: url("assets/dash/left-running4-focused.svg");
}

#dashtodockContainer.right .dash-item-container > StWidget.running1 {
  background-image: url("assets/dash/right-running1.svg");
}

#dashtodockContainer.right .dash-item-container > StWidget.running1.focused {
  background-image: url("assets/dash/right-running1-focused.svg");
}

#dashtodockContainer.right .dash-item-container > StWidget.running2 {
  background-image: url("assets/dash/right-running2.svg");
}

#dashtodockContainer.right .dash-item-container > StWidget.running2.focused {
  background-image: url("assets/dash/right-running2-focused.svg");
}

#dashtodockContainer.right .dash-item-container > StWidget.running3 {
  background-image: url("assets/dash/right-running3.svg");
}

#dashtodockContainer.right .dash-item-container > StWidget.running3.focused {
  background-image: url("assets/dash/right-running3-focused.svg");
}

#dashtodockContainer.right .dash-item-container > StWidget.running4 {
  background-image: url("assets/dash/right-running4.svg");
}

#dashtodockContainer.right .dash-item-container > StWidget.running4.focused {
  background-image: url("assets/dash/right-running4-focused.svg");
}

#dashtodockContainer.top .dash-item-container > StWidget.running1 {
  background-image: url("assets/dash/top-running1.svg");
}

#dashtodockContainer.top .dash-item-container > StWidget.running1.focused {
  background-image: url("assets/dash/top-running1-focused.svg");
}

#dashtodockContainer.top .dash-item-container > StWidget.running2 {
  background-image: url("assets/dash/top-running2.svg");
}

#dashtodockContainer.top .dash-item-container > StWidget.running2.focused {
  background-image: url("assets/dash/top-running2-focused.svg");
}

#dashtodockContainer.top .dash-item-container > StWidget.running3 {
  background-image: url("assets/dash/top-running3.svg");
}

#dashtodockContainer.top .dash-item-container > StWidget.running3.focused {
  background-image: url("assets/dash/top-running3-focused.svg");
}

#dashtodockContainer.top .dash-item-container > StWidget.running4 {
  background-image: url("assets/dash/top-running4.svg");
}

#dashtodockContainer.top .dash-item-container > StWidget.running4.focused {
  background-image: url("assets/dash/top-running4-focused.svg");
}

#dashtodockContainer.bottom .dash-item-container > StWidget.running1 {
  background-image: url("assets/dash/bottom-running1.svg");
}

#dashtodockContainer.bottom .dash-item-container > StWidget.running1.focused {
  background-image: url("assets/dash/bottom-running1-focused.svg");
}

#dashtodockContainer.bottom .dash-item-container > StWidget.running2 {
  background-image: url("assets/dash/bottom-running2.svg");
}

#dashtodockContainer.bottom .dash-item-container > StWidget.running2.focused {
  background-image: url("assets/dash/bottom-running2-focused.svg");
}

#dashtodockContainer.bottom .dash-item-container > StWidget.running3 {
  background-image: url("assets/dash/bottom-running3.svg");
}

#dashtodockContainer.bottom .dash-item-container > StWidget.running3.focused {
  background-image: url("assets/dash/bottom-running3-focused.svg");
}

#dashtodockContainer.bottom .dash-item-container > StWidget.running4 {
  background-image: url("assets/dash/bottom-running4.svg");
}

#dashtodockContainer.bottom .dash-item-container > StWidget.running4.focused {
  background-image: url("assets/dash/bottom-running4-focused.svg");
}

/* Simple Dock */
#dash:desktop {
  background-color: #F5F5F5;
}

/* GPaste */
.popup-menu .search-entry {
  color: rgba(87, 79, 74, 0.87);
  selection-background-color: #48b9c7;
  selected-color: #FFFFFF;
  background-color: rgba(255, 255, 255, 0.01);
  border-color: transparent;
  box-shadow: inset 0 -1px rgba(87, 79, 74, 0.26);
}

.popup-menu .search-entry:focus {
  border-color: transparent;
  box-shadow: inset 0 -2px #faa41a;
  color: rgba(87, 79, 74, 0.87);
}

.popup-menu .search-entry .search-entry-icon {
  color: rgba(87, 79, 74, 0.38);
}

.popup-menu .search-entry:hover .search-entry-icon, .popup-menu .search-entry:focus .search-entry-icon {
  color: rgba(87, 79, 74, 0.87);
}

/*****************
 * GNOME Classic *
 *****************/
#panel.bottom-panel, #panel.bottom-panel.solid {
  height: 32px;
  border-top-width: 1px;
  border-bottom-width: 0;
  border-color: #252220;
  background-color: #252220;
  background-gradient-drection: vertical;
  background-gradient-start: #252220;
  background-gradient-end: #252220;
  color: rgba(87, 79, 74, 0.87);
}

#panel {
  height: 32px;
  border-top-width: 0;
  border-bottom-width: 1px;
  border-color: #252220;
  background-color: #252220;
  background-gradient-drection: vertical;
  background-gradient-start: #252220;
  background-gradient-end: #252220;
  color: rgba(87, 79, 74, 0.87);
}

#panel .panel-button:active, #panel .panel-button:focus {
  background-color: #252220;
  background-gradient-drection: vertical;
  background-gradient-start: #252220;
  background-gradient-end: #252220;
}
